@@ -1,9 +1,11 @@
 from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import ForeignKey
+from sqlalchemy.orm import relationship
 from marshmallow import fields
 from marshmallow import Schema
 from marshmallow import post_load
+from .product import ProductSchema
 
 from .base import Base
 
@@ -17,6 +19,8 @@ class OrderItem(Base):
     quantity = Column(Integer, nullable=False)
     price = Column(Integer, nullable=False)
 
+    product = relationship('Product', primaryjoin='Product.id == OrderItem.product_id')
+
 
 class OrderItemSchema(Schema):
 
@@ -28,6 +32,8 @@ class OrderItemSchema(Schema):
     quantity = fields.Integer()
     price = fields.Integer()
 
+    product = fields.Nested(ProductSchema, many=False)
+
     @post_load
-    def make_address(self, data, **kwargs):
+    def make_order_item(self, data, **kwargs):
         return OrderItem(**data)
