@@ -17,7 +17,7 @@ class Review(Base):
     product_id = Column(ForeignKey('products.id'), nullable=False)
     name = Column(String(30), nullable=False)
     rating = Column(Integer, nullable=False)
-    description = Column(String(100), nullable=False)
+    description = Column(String(100), nullable=True)
 
 
 class ReviewSchema(Schema):
