@@ -22,6 +22,7 @@ class User(Base):
     registration_date = Column(DateTime, nullable=False, server_default=func.now())
     activation_date = Column(DateTime, nullable=True)
     updated_date = Column(DateTime, nullable=True, onupdate=func.now())
+    role = Column(String(5), nullable=False, server_default='User')
 
 
 class UserSchema(Schema):
@@ -36,7 +37,8 @@ class UserSchema(Schema):
     registration_date = fields.DateTime(data_key='registrationDate')
     activation_date = fields.DateTime(data_key='activationDate')
     updated_date = fields.DateTime(data_key='updatedDate')
+    role = fields.String()
 
     @post_load
-    def make_address(self, data, **kwargs):
+    def make_user(self, data, **kwargs):
         return User(**data)
